==> cms-db_v0.7.9.tar.gz: admin/fileperms.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('fileperms');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_fileperms') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('desc_fileperms') ?></h1>
<?php if (isset($_GET['set'])) { ?>
<?php if ($_GET['set'] == 'ok') { ?>
<p class="hint">
	<?php locale('desc_fileperms-changed') ?>
</p>
<?php } else { ?>
<p class="error">
	<?php locale('desc_fileperms-error') ?>
</p>
<?php } ?>
<?php } ?>
<p>
	<?php locale('desc_fileperms1') ?>
</p>
<p>
<?php
include('fileperms.inc.php');
startFilePerms();
displayPermissions('../data');
endFilePerms();
?>
</p>
<p>
	<?php locale('desc_fileperms2') ?>
</p>
<?php if (checkuser2('root')) { ?>
<p>
	<form action="setperms.php?<?php echo SID ?>" method="post">
		<?php locale('desc_setperms') ?><br />
		<?php locale('label_folders') ?> <input type="text" name="perms_folder" value="0755" /><br />
		<?php locale('label_files') ?> <input type="text" name="perms_file" value="0644" /><br />
		<input type="submit" value="<?php locale('button_save') ?>" />
	</form>
</p>
<?php } ?>
<p>
	<i><?php locale('desc_windows') ?></i>
</p>

</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/fileperms.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('fileperms');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_fileperms') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('desc_fileperms') ?></h1>
<?php if (isset($_GET['set'])) { ?>
<?php if ($_GET['set'] == 'ok') { ?>
<p class="hint">
	<?php locale('desc_fileperms-changed') ?>
</p>
<?php } else { ?>
<p class="error">
	<?php locale('desc_fileperms-error') ?>
</p>
<?php } ?>
<?php } ?>
<p>
	<?php locale('desc_fileperms1') ?>
</p>
<p>
<?php
include('fileperms.inc.php');
startFilePerms();
displayPermissions('../data');
endFilePerms();
?>
</p>
<p>
	<?php locale('desc_fileperms2') ?>
</p>
<?php if (checkuser2('root')) { ?>
<p>
	<form action="setperms.php?<?php echo SID; csrf_protection_get_html() ?>" method="post">
		<?php locale('desc_setperms') ?><br />
		<?php locale('label_folders') ?> <input type="text" name="perms_folder" value="0755" /><br />
		<?php locale('label_files') ?> <input type="text" name="perms_file" value="0644" /><br />
		<input type="submit" value="<?php locale('button_save') ?>" />
	</form>
</p>
<?php } ?>
<p>
	<i><?php locale('desc_windows') ?></i>
</p>

</body>
</html>
